@@ -1,4 +1,4 @@
-# $Id: runit.mkinmod.R 59 2010-07-28 12:29:15Z jranke $
+# $Id: runit.mkinmod.R 64 2010-09-01 13:33:51Z jranke $
 
 # Copyright (C) 2010 Johannes Ranke
 # Contact: mkin-devel@lists.berlios.de
@@ -25,7 +25,9 @@ test.mkinmod.SFO <- function()
   )
   SFO.parms <- c("k_parent_sink")
   SFO.map <- list(parent = c(SFO = "parent"))
-  SFO <- list(diffs = SFO.diffs, parms = SFO.parms, map = SFO.map)
+  SFO.coefmat <- matrix("- k_parent_sink", dimnames = list("parent", "parent"))
+  SFO <- list(diffs = SFO.diffs, parms = SFO.parms, map = SFO.map, 
+    coefmat = SFO.coefmat)
   class(SFO) <- "mkinmod"
   SFO.1 <- mkinmod(
     parent = list(type = "SFO", to = NULL, sink = TRUE)
@@ -59,7 +61,13 @@ test.mkinmod.SFORB <- function()
   )
   SFORB.parms <- c("k_parent_free_sink", "k_parent_free_bound", "k_parent_bound_free")
   SFORB.map <- list(parent = c(SFORB = "parent_free", SFORB = "parent_bound"))
-  SFORB <- list(diffs = SFORB.diffs, parms = SFORB.parms, map = SFORB.map)
+  vars <- paste("parent", c("free", "bound"), sep="_")
+  SFORB.coefmat <- matrix(
+    c("- k_parent_free_sink - k_parent_free_bound", "k_parent_bound_free",
+      "k_parent_free_bound", "- k_parent_bound_free"), nrow=2, byrow=TRUE, 
+    dimnames=list(vars, vars))
+  SFORB <- list(diffs = SFORB.diffs, parms = SFORB.parms, 
+    map = SFORB.map, coefmat = SFORB.coefmat)
   class(SFORB) <- "mkinmod"
   SFORB.mkinmod <- mkinmod(
     parent = list(type = "SFORB", to = NULL, sink=TRUE)
@@ -75,7 +83,12 @@ test.mkinmod.SFO_SFO <- function()
   )
   SFO_SFO.parms <- c("k_parent_sink", "k_m1_sink", "k_parent_m1")
   SFO_SFO.map <- list(parent = c(SFO = "parent"), m1 = c(SFO = "m1"))
-  SFO_SFO <- list(diffs = SFO_SFO.diffs, parms = SFO_SFO.parms, map = SFO_SFO.map)
+  vars <- c("parent", "m1")
+  SFO_SFO.coefmat <- matrix(c("- k_parent_sink - k_parent_m1", 
+          "0", "k_parent_m1", "- k_m1_sink"), nrow=2, byrow=TRUE,
+      dimnames=list(vars, vars))
+  SFO_SFO <- list(diffs = SFO_SFO.diffs, parms = SFO_SFO.parms, 
+    map = SFO_SFO.map, coefmat = SFO_SFO.coefmat)
   class(SFO_SFO) <- "mkinmod"
   SFO_SFO.mkinmod <- mkinmod(
     parent = list(type = "SFO", to = "m1", sink=TRUE),
@@ -93,7 +106,14 @@ test.mkinmod.SFO_SFO2 <- function()
   )
   SFO_SFO2.parms <- c("k_parent_sink", "k_m1_sink", "k_m2_sink", "k_parent_m1", "k_parent_m2")
   SFO_SFO2.map <- list(parent = c(SFO = "parent"), m1 = c(SFO = "m1"), m2 = c(SFO = "m2"))
-  SFO_SFO2 <- list(diffs = SFO_SFO2.diffs, parms = SFO_SFO2.parms, map = SFO_SFO2.map)
+  vars <- c("parent", "m1", "m2")
+  SFO_SFO2.coefmat <- matrix(
+      c("- k_parent_sink - k_parent_m1 - k_parent_m2", "0", "0",
+          "k_parent_m1", "- k_m1_sink", "0",
+          "k_parent_m2", "0", "- k_m2_sink"), nrow=3, byrow=TRUE,
+      dimnames=list(vars, vars))
+  SFO_SFO2 <- list(diffs = SFO_SFO2.diffs, parms = SFO_SFO2.parms, 
+      map = SFO_SFO2.map, coefmat = SFO_SFO2.coefmat)
   class(SFO_SFO2) <- "mkinmod"
   SFO_SFO2.mkinmod <- mkinmod(
     parent = list(type = "SFO", to = c("m1", "m2"), sink=TRUE),
@@ -110,9 +130,16 @@ test.mkinmod.FOMC_SFO2 <- function()
     m1 = "d_m1 = - k_m1_sink * m1 + f_to_m1 * (alpha/beta) * ((time/beta) + 1)^-1 * parent",
     m2 = "d_m2 = - k_m2_sink * m2 + (1 - f_to_m1) * f_to_m2 * (alpha/beta) * ((time/beta) + 1)^-1 * parent"
   )
-  FOMC_SFO2.parms <- c("alpha", "beta", "k_m1_sink", "k_m2_sink", "f_to_m1", "f_to_m2")
-  FOMC_SFO2.map <- list(parent = c(FOMC = "parent"), m1 = c(SFO = "m1"), m2 = c(SFO = "m2"))
-  FOMC_SFO2 <- list(diffs = FOMC_SFO2.diffs, parms = FOMC_SFO2.parms, map = FOMC_SFO2.map)
+  FOMC_SFO2.parms <- c("alpha", "beta", "k_m1_sink", "k_m2_sink", 
+    "f_to_m1", "f_to_m2")
+  FOMC_SFO2.map <- list(parent = c(FOMC = "parent"), 
+    m1 = c(SFO = "m1"), 
+    m2 = c(SFO = "m2"))
+  FOMC_SFO2.ff <- c(
+    m1 = "f_to_m1", 
+    m2 = "(1 - f_to_m1) * f_to_m2")
+  FOMC_SFO2 <- list(diffs = FOMC_SFO2.diffs, parms = FOMC_SFO2.parms, 
+    map = FOMC_SFO2.map, ff = FOMC_SFO2.ff)
   class(FOMC_SFO2) <- "mkinmod"
   FOMC_SFO2.mkinmod <- mkinmod(
     parent = list(type = "FOMC", to = c("m1", "m2"), sink=TRUE),
